#
# spec file for package python-Pygments
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#
%if 0%{?suse_version} > 1500
%bcond_without libalternatives
%else
%bcond_with libalternatives
%endif
%{?sle15_python_module_pythons}
Name:           python-Pygments
Version:        2.19.1
Release:        1.1
Summary:        A syntax highlighting package written in Python
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://pygments.org
Source:         https://files.pythonhosted.org/packages/source/p/pygments/pygments-%{version}.tar.gz
# PATCH-FIX-UPSTREAM skip-wcag-contrast-ratio.patch gh#pygments/pygments!2564 mcepl@suse.com
# Don't make wcag-contrast-ratio mandatory for testing
Patch0:         skip-wcag-contrast-ratio.patch
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 7}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros >= 20210929
#!BuildIgnore:  ca-certificates:p11-kit
#!BuildIgnore:  ca-certificates:p11-kit-tools
Provides:       python-pygments = %{version}
Obsoletes:      python-pygments < %{version}
BuildArch:      noarch
%if %{with libalternatives}
BuildRequires:  alts
Requires:       alts
%else
Requires(post): update-alternatives
Requires(postun): update-alternatives
%endif
%python_subpackages

%description
Pygments is a generic syntax highlighter for general use in all kinds of software
such as forum systems, wikis or other applications that need to prettify
source code. Highlights are:

 * a wide range of common languages and markup formats is supported
 * support for new languages and formats can be added
 * a number of output formats, presently HTML, LaTeX, RTF, SVG, all image
   formats that PIL supports and ANSI sequences
 * it is usable as a command-line tool and as a library
 * highlights Brainfuck

%prep
%autosetup -n pygments-%{version} -p1
# Remove unneeded executable bit
chmod -x pygments/formatters/_mapping.py pygments/lexers/gsql.py

%build
%pyproject_wheel

%install
%pyproject_install
install -Dm0644 doc/pygmentize.1 %{buildroot}%{_mandir}/man1/pygmentize.1
%python_clone -a %{buildroot}%{_bindir}/pygmentize
%python_clone -a %{buildroot}%{_mandir}/man1/pygmentize.1
%{python_expand rm -rf %{buildroot}%{$python_sitelib}/tests
%fdupes %{buildroot}%{$python_sitelib}
}

%check
%pytest

%pre
# If libalternatives is used: Removing old update-alternatives entries.
%python_libalternatives_reset_alternative pygmentize

%post
%{python_install_alternative pygmentize pygmentize.1}

%postun
%python_uninstall_alternative pygmentize

%files %{python_files}
%license LICENSE
%doc AUTHORS CHANGES
%python_alternative %{_bindir}/pygmentize
%python_alternative %{_mandir}/man1/pygmentize.1%{ext_man}
%{python_sitelib}/pygments
%{python_sitelib}/pygments-%{version}*-info

%changelog
* Thu Jan 23 2025 Markéta Machová <mmachova@suse.com>
- Drop dependency on ca-certificates-mozilla-prebuilt to really
  avoid buildcycles
* Mon Jan  6 2025 Benoît Monin <benoit.monin@gmx.fr>
- update to version 2.19.1:
  * Ini: Fix quoted string regression introduced in 2.19.0
  * Lua: Fix a regression introduced in 2.19.0
- additional changes from version 2.19.0:
  * New lexers:
    + CodeQL (#2819)
    + Debian Sources (#2788, #2747)
    + Gleam (#2662)
    + GoogleSQL (#2820, #2814)
    + JSON5 (#2734, #1880)
    + Maple (#2763, #2548)
    + NumbaIR (#2433)
    + PDDL (#2799, #2616)
    + Rego (#2794)
    + TableGen (#2751)
    + Vue.js (#2832)
  * Updated lexers:
    + BQN: Various improvements (#2789)
    + C#: Fix number highlighting (#986, #2727), add ``file``
    keyword (#2726, #2805, #2806), add various other keywords
    (#2745, #2770)
    + CSS: Add ``revert`` (#2766, #2775)
    + Debian control: Add ``Change-By`` field (#2757)
    + Elip: Improve punctuation handling (#2651)
    + Igor: Add ``int`` (#2801)
    + Ini: Fix quoted strings with embedded comment characters
    (#2767, #2720)
    + Java: Support functions returning types containing a question
    mark (#2737)
    + JavaScript: Support private identiiers (#2729, #2671)
    + LLVM: Add ``splat``, improve floating-point number parsing
    (#2755)
    + Lua: Improve variable detection, add built-in functions
    (#2829)
    + Macaulay2: Update to 1.24.11 (#2800)
    + PostgreSQL: Add more ``EXPLAIN`` keywords (#2785),
    handle ``/`` (#2774)
    + S-Lexer: Fix keywords (#2082, #2750)
    + TransactSQL: Fix single-line comments (#2717)
    + Turtle: Fix triple quoted strings (#2744, #2758)
    + Typst: Various improvements (#2724)
    + Various: Add ``^`` as an operator to Matlab, Octave and
    Scilab (#2798)
    + Vyper: Add ``staticcall`` and ``extcall`` (#2719)
  * Mark file extensions for ``HTML/XML+Evoque`` as aliases (#2743)
  * Add a color for ``Operator.Word`` to the ``rrt`` style (#2709)
  * Fix broken link in the documentation (#2803, #2804)
  * Drop executable bit where not needed (#2781)
  * Reduce Mojo priority relative to Python in ``analyze_text´`
    (#2771, #2772)
  * Fix documentation builds (#2712)
  * Match example file names to the lexer's name (#2713, #2715)
  * Ensure lexer metadata is present (#2714)
  * Search more directories on macOS for fonts (#2809)
  * Improve test robustness (#2812)
* Sat Aug  3 2024 Benoît Monin <benoit.monin@gmx.fr>
- fix build by forcing pip to use the prebuilt CA bundle
* Thu Jul 11 2024 Dirk Müller <dmueller@suse.com>
- add buildignores to avoid bootstrap buildcycle
  p11-kit/gtk-doc/python-Pygments which comes via
  pip/ca-certificates
* Mon May  6 2024 Benoît Monin <benoit.monin@gmx.fr>
- update to version 2.18.0:
  * New lexers:
    + Janet (#2557)
    + Lean 4 (#2618, #2626)
    + Luau (#2605)
    + Mojo (#2691, #2515)
    + org-mode (#2628, #2636)
    + Promela (#2620)
    + Soong / ``Android.bp`` (#2659)
    + Tact (#2571)
    + Typst (#2596)
  * Updated lexers:
    + Awk: recognize ternary operator (#2687)
    + Bash: add ``openrc`` alias (#2599, #2371)
    + Coq: add keywords, lex more vernacular command arguments,
    produce fewer tokens on heading comments (#2678)
    + DNS zone files: Fix comment parsing (#2595)
    + Hy: Support unicode literals (#1126)
    + Inform6: Update to Inform 6.42 (#2644)
    + lean: Fix name handling (#2614)
    + Logtalk: add ``uninstantiation`` keyword and recognize escape
    sequences (#2619)
    + Macaulay2: Update to 1.23 (#2655)
    + Python: fix highlighting of soft keywords before ``None``/
    ``True``/``False``
    + reStructuredText: use ``Token.Comment`` for comments instead
    of ``Comment.Preproc`` (#2598)
    + Rust: highlight ``:``, ``::`` and ``->`` as ``Punctuation``
    and whitespace as ``Whitespace``, instead of ``Text`` in both
    cases (#2631)
    + Spice: Add keywords (#2621)
    + SQL Explain: allow negative numbers (#2610)
    + Swift: Support multiline strings (#2681)
    + ThingsDB: add constants and new functions; support template
    strings (#2624)
    + UL4: support nested ``<?doc?>`` and ``<?note?>`` tags (#2597)
    + VHDL: support multi-line comments of VHDL-2008 (#2622)
    + Wikitext: Remove ``kk-*`` in ``variant_langs`` (#2647)
    + Xtend: Add ``val`` and ``var`` (#2602)
  * New styles:
    + Coffee (#2609)
  * Make background colors in the image formatter work with Pillow
    10.0 (#2623)
  * Require Python 3.8. As a result, the ``importlib-metadata``
    package is no longer needed for fast plugin discovery on Python
    3.7. The ``plugins`` extra (used as, e.g., ``pip install
    pygments[plugins]``) is kept for backwards compatibility but
    now has no effect. (#2601)
  * Require the ``url`` attribute for lexers inside Pygments, add
    it to many lexers (#2588)
  * Replace Pyflakes linter with Ruff (#2592)
  * Add macOS CI (#2594)
  * Built-in lexers now declare the version of Pygments in which
    they were added in a required ``version_added`` lexer attribute
    instead of a ``.. versionadded::`` directive in the docstring
    (#2589, #2634)
  * The ``url`` attribute is now required for built-in lexers and
    has been added to all existing lexers (#2588)
  * The RTF formatter supports line number and line highlighting
    now (#1217, #2654)
  * Add ``\sa0`` keyword in the RTF formatter (#1111, #2607)
  * Register ``pycon`` as an alias for the Python console lexer
    (#2697)
  * Add MIME-Type for ``DesktopLexer`` (#2613)
  * Fix native style to meet WCAG AA guidelines (#2600)
  * Fix typo in documentation (#2672)
  * Use format strings consistently (#2661)
  * Add ``__class_getitem__`` to ``Formatter`` to improve typing
    support (#2665)
- set the base python version to 3.8
- drop the requirement of importlib-metadata:
  already included in python 3.8 and above
- remove unneeded executable bit from some python files
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 2.17.2:
  * Fix a packaging issue on macOS
  * Updated lexers:
  * TOML: Fix bug making lexing of single-quoted strings too
    eager
  * Cypher: fix comment matching, add missing keywords
  * Fortran: add ``elseif`` keyword
  * Lean: make it available as ``lean3``, in preparation for
  * a possible switch to ``lean`` highlighting as Lean 4
  * JSON: add MIME types and file extensions for several line-
    delimited JSON formats
  * Nix: many improvements
  * OCaml: Add ``and`` keyword, remove ``value`` from keywords
  * Python: add ``starlark`` and ``bazel`` aliases
  * Snowball: Treat ``len`` like ``size``
  * Spice: add ``panic`` keyword and ``->`` operator
  * squid.conf: fix catastrophic backtracking
  * TOML: rewritten, with many fixes
  * Turtle: support blank nodes
  * Wikitext: fix erroneous highlighting of LanguageConverter
    markup
  * CMake: support ``[=[ bracketed arguments ]=]```
  * Fix ctags support and tests
  * Include ``Lexer.add_filter`` in the documentation
  * Add a ``Lean3Lexer`` alias
  * The ``pygments.styles`` module contains a new ``STYLES``
    variable with a dictionary of built-in styles.  The old
    ``STYLE_MAP`` variable, which uses a different format,
    is kept for backwards compatibility.
  * On Windows, add a new installation extra (``windows-
    terminal``) which pulls in dependencies for colored
    console output. See :doc:`cmdline` for more details.
  * Support more file types in ``autopygmentize`` script
  * Change color of numbers in ``rrt`` style
  * Fix error when trying to look up plugin formatters by file
    extension of the output format
  * Use Hatchling as a build backend instead of setuptools.
  * This change is transparent to most users. Distribution
    packagers who build without build isolation need to add
    hatchling as a build dependency and remove setuptools.
    People downloading source distributions and wheels from PyPI
    directly should note that they now have ``pygments`` in their
    file names instead of ``Pygments``.
  * Improve the test framework to also check for lost tokens when
    processing the snippets and example files
  * Improve the *Dracula* style definition to make it easier to
    maintain
* Sun Nov  5 2023 Matěj Cepl <mcepl@cepl.eu>
- Add skip-wcag-contrast-ratio.patch to make
  python-wcag-contrast-ratio just optional dependency
  (gh#pygments/pygments!2564).
* Mon Aug  7 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to version 2.16.1:
  * Fix native style missing from style list (#2484)
- additional changes from version 2.16.0:
  * New lexers:
    + ASN.1 (#2462)
    + Blueprint (#2434)
    + BQN (#2472)
    + DNS zone files (#2464)
    + GraphQL (#2428)
    + Linux desktop files (following the specification of the
    Freedesktop group, formerly known as XDG) (#2470)
    + NVIDIA PTX (#2432)
    + OpenSCAD (#2449)
    + systemd (#2470)
    + TLS presentation language (#2455)
    + Verifpal (#2430)
    + YARA (#2453)
  * Updated lexers:
    + ASC: Add application/pem-certificate-chain mimetype (#2471)
    + C/C++: Refine keyword lists (#2421, #2422)
    + Carbon: Fix long processing times on invalid input, fix
    number lexing (#2454, #2456)
    + Elpi: Handle quotations (#2419)
    + Go: Support additional built-ins (#2481)
    + HTTP: Support empty headers (#2461), support more general
    methods (#2460), also recognize responses in analyse_text
    implementation (#2460), and highlight URL encoded data
    (#2465, #1620)
    + Igor Pro: Update to Igor Pro 9 (#2482)
    + lean: Recognize expressions nested within attributes (#1817)
    + Macaulay2: Update builtins (#2457)
    + Markdown: Allow extra characters after language name in code
    blocks (#2437)
    + NestedText: Update to version 3 (#2459)
    + scdoc: Improve language guessing implementation (#2402)
    + Spice: Update to latest version (#2476)
    + Transact SQL: Add Pre-sorted Group keyword (#2417)
    + Uxntal: Update for current runes (#2424)
    + Wikitext: Fix templates in wiki links; fix a language
    converter false positive; add bold italic markup (#2447)
  * Add Generic.EmphStrong token for bold italic markup (#2444)
  * Add Lightbulb style (#2474)
  * Improve contrast in Monokai style (#2448)
  * Add documentation how to create terminal code highlighting
    commands (#2131, #2425)
  * Add support for loading TrueType fonts to the ImageFormatter
    (#1960)
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Wed Apr 19 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to 2.15.1:
  * Updated lexers:
    + Java properties: Fix catastrophic backtracking (#2356, #2404)
  * Fix Python console traceback lexing being too strict
    and sometimes reordering output (#2407, #2410, #2412)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Apr 10 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to 2.15.0:
  * Added lexers:
    + Carbon (#2362, #2365, #2366, #2367, #2368, #2369, #2370)
    + Dax (#2335, #2345)
    + MediaWiki Wikitext (#2373, #827)
    + PostgreSQL Explain (#2398)
    + WGSL (WebGPU Shading Language) (#2386)
    + X++ (#2339)
  * Updated lexers:
    + AMDGPU: Add support for scratch_ instructions, the attr*.*
    argument, as well as the off modifier (#2327).
    + APDL: Miscellaneous improvements (#2314)
    + bash/tcsh:
  - Move break to keywords (#2377)
  - Improve bash math expansion lexing (#2255, #2353)
    + Chapel: Support attributes (#2376)
    + CMake: Implement bracket style comments (#2338, #2354)
    + CSS: Improve lexing of numbers inside function calls (#2382,
    [#2383])
    + diff: Support normal diff syntax, as opposed to unified diff
    syntax (#2321)
    + GLSL, HLSL:
  - Support line continuations in preprocessor code (#2350)
  - Improve preprocessor directive handling (#2357)
    + LilyPond: minor update of builtins
    + PHP: support attributes (#2055, #2347, #2360), fix anonymous
    classes without parameters (#2359), improve lexing of
    variable variable syntax (#2358)
    + Python:
  - Add missing builtins (#2334)
  - Fix inconsistent lexing of None (#2406)
    + Rebol/Red: Don’t require script headers (#2348, #2349)
    + Spice: Update keywords (#2336)
    + SQL+Jinja (analyse_text method): Fix catastrophic
    backtracking (#2355)
    + Terraform: Add hcl alias (#2375)
  * Declare support for Python 3.11 and drop support for Python 3.6
    (#2324).
  * Update native style to improve contrast (#2325).
  * Update github-dark` style to match latest Primer style (#2401)
  * Revert a change that made guessing lexers based on file names
    slower on Python 3.10 and older (#2328).
  * Fix some places where a locale-dependent encoding could
    unintentionally be used instead of UTF-8 (#2326).
  * Fix Python traceback handling (#2226, #2329).
  * Groff formatter: sort color definitions for reproducibility
    (#2343)
  * Move project metadata to pyproject.toml, remove setup.py and
    setup.cfg (#2342)
  * The top-level Makefile has been removed.
- increase required python version to 3.7
- set a minimum version for setuptools to match the requirement
  from upstream
- since setup.py is gone:
  * require pip and wheel to build
  * use pyproject macros to build and install
* Mon Jan  2 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to 2.14.0:
  * Added lexers:
    + Arturo (#2259)
    + GAP session (#2211)
    + Fift (#2249)
    + func (#2232)
    + Jsonnet (#2239)
    + Minecraft schema (#2276)
    + MIPS (#2228)
    + Phix (#2222)
    + Portugol (#2300)
    + TL-b (#2247)
    + World of Warcraft TOC format (#2244, #2245)
    + Wren (#2271)
  * Updated lexers:
    + Abap: Update keywords (#2281)
    + Alloy: Update for Alloy 6 (#1963)
    + C family (C, C++ and many others):
  - Fix an issue where a chunk would be wrongly recognized as a
    function definition due to braces in comments (#2210)
  - Improve parantheses handling for function definitions
    (#2207, #2208)
    + C#: Fix number and operator recognition (#2256, #2257)
    + CSound: Updated builtins (#2268)
    + F#: Add .fsx file extension (#2282)
    + gas (GNU assembler): recognize braces as punctuation (#2230)
    + HTTP: Add CONNECT keyword (#2242)
    + Inform 6: Fix lexing of properties and doubles (#2214)
    + INI: Allow comments that are not their own line
    (#2217, #2161)
    + Java properties: Fix issue with whitespace-delimited keys,
    support comments starting with ! and escapes, no longer
    support undocumented ; and // comments (#2241)
    + LilyPond: Improve heuristics, add \maxima duration (#2283)
    + LLVM: Add opaque pointer type (#2269)
    + Macaulay2: Update keywords (#2305)
    + Minecraft-related lexers (SNB and Minecraft function) moved
    to pygments.lexers.minecraft (#2276)
    + Nim: General improvements (#1970)
    + Nix: Fix single quotes inside indented strings (#2289)
    + Objective J: Fix catastrophic backtracking (#2225)
    + NASM: Add support for SSE/AVX/AVX-512 registers as well as
    'rel' and 'abs' address operators (#2212)
    + Powershell:
  - Add local: keyword (#2254)
  - Allow continuations without markers (#2262, #2263)
    + Solidity: Add boolean operators (#2292)
    + Spice: Add enum keyword and fix a bug regarding binary,
    hexadecimal and octal number tokens (#2227)
    + YAML: Accept colons in key names (#2277)
  * Fix make mapfiles when Pygments is not installed in editable
    mode (#2223)
  * Support more filetypes and compression types in autopygmentize
    (#2219)
  * Merge consecutive tokens in Autohotkey, Clay (#2248)
  * Add .nasm as a recognized file type for NASM (#2280)
  * Add *Spec.hs as a recognized file type for HSpec (#2308)
  * Add *.pyi (for typing stub files) as a recognized file type for
    Python (#2331)
  * The HTML lexer no longer emits empty spans for whitespace
    (#2304)
  * Fix IRCFormatter inserting linenumbers incorrectly (#2270)
- set minimum python version to 3.6:
  increased upstream -- gh#pygments/pygments#2059
- remove lxml BuildRequires:
  dropped upstream -- gh#pygments/pygments#2301
- remove skip_python2: python >= 3.6 is already required
- drop python_module macro definition: provided by
  python-rpm-macros
* Thu Aug 18 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to 2.13.0:
  * Added lexers:
    + COMAL-80 (#2180)
    + JMESPath (#2174, #2175, #2179, #2182)
    + Sql+Jinja (#2148)
  * Updated lexers:
    + Ada: support Ada 2022 (#2121); disable recognition of
    namespaces because it disturbs lexing of aspects (#2125)
    + Agda: allow straight quotes in module names (#2163)
    + C family (C, C++ and many others): allow comments between
    elements of function headers, e.g. between the arguments and
    the opening brace for the body (#1891)
    + C++: Resolve several cases of Error tokens (#2207, #2208)
    + Coq: add some common keywords, improve recognition of Set and
    qualified identifiers (#2158)
    + F*: Allow C-style comments anywhere in a line
    + Fortran: fix catastrophic backtracking with backslashes in
    strings (#2194)
    + Go: add support for generics (#2167)
    + Inform: update for version 6.40 (#2190)
    + Isabelle: recognize cartouches (#2089)
    + Java: support multiline strings aka. text blocks (#2132)
    + Kotlin: add value modifier (#2142)
    + LilyPond: add some missing builtins
    + Macaulay2: update builtins (#2139)
    + Matlab session: fix traceback when a line continuation
    ellipsis appears in the output (#2166)
    + .NET: add aliases for LibreOffice Basic, OpenOfficeBasic and
    StarOffice Basic (#2170)
    + Nim: use Name.Builtin instead of Keyword.Type (#2136)
    + PHP: fix \"$var\" inside strings (#2105)
    + Python: only recognize \N, \u and \U escape sequences in
    string literals, but not in bytes literals where they are not
    supported (#2204)
    + Tcl: support ${name} variables (#2145)
    + Terraform: accept leading whitespace for << heredoc
    delimiters (#2162)
    + Teraterm: Various improvements (#2165)
    + Spice: add support for the recently added features including
    more builtin functions and bin, oct, hex number formats
    (#2206)
  * Added styles:
    + GitHub dark (#2192)
    + StarOffice (#2168)
    + Nord (nord and nord-darker; #2189, #1799, #1678)
  * Pygments now tries to use the importlib.metadata module to
    discover plugins instead of the slower pkg_resources (#2155).
  * Silently ignore BrokenPipeError in the command-line interface
    (#2193).
  * The HtmlFormatter now uses the linespans attribute for
    anchorlinenos if the lineanchors attribute is unset (#2026).
  * The highlight, lex and format functions no longer wrongly
    report "argument must be a lexer/formatter instance, not a
    class" in some cases where this is not the actual problem
    (#2123).
  * Fix warnings in doc build (#2124).
  * The codetagify filter now recognizes FIXME tags by default
    (#2150).
  * The pygmentize command now recognizes if the COLORTERM
    environment variable is set to a value indicating that
    true-color support is available.  In that case, it uses the
    TerminalTrueColorFormatter by default (#2160)
  * Remove redundant caches for filename patterns (#2153)
  * Use new non-deprecated Pillow API for text bounding box in
    ImageFormatter (#2198)
  * Remove default_style (#930, #2183)
  * Stop treating DeprecationWarnings as errors in the unit tests
    (#2196)
* Mon Jul 18 2022 Matej Cepl <mcepl@suse.com>
- Add BR of wcag-contrast-ratio to enable more tests.
* Mon Jul 18 2022 Matej Cepl <mcepl@suse.com>
- Removing a test file is too much a hack for me
* Fri Jul 15 2022 Ben Greiner <code@bnavigator.de>
- Don't fall back to setuptools but to importlib-metadata for
  plugin loading. (If a package for 15.X would be build, but
  Pytest 7 is required for testing -- gh#pygments/pygments#2080)
* Sun May 15 2022 Dirk Müller <dmueller@suse.com>
- update to 2.12.0:
  - Added lexers:
  * Cplint (#2045)
  * Macaulay2 (#1791)
  * Minecraft (#2107)
  * Qlik (#1925)
  * ``UnixConfigLexer`` for "colon-separated" config files, like ``/etc/passwd`` (#2112)
  - Updated lexers:
  * Agda: Update keyword list (#2017)
  * C family: Fix identifiers after ``case`` statements (#2084)
  * Clojure: Highlight ratios (#2042)
  * Csound: Update to 6.17 (#2064)
  * CSS: Update the list of properties (#2113)
  * Elpi:
  - Fix catastrophic backtracking (#2053, #2061)
  - Fix handling of ``->`` (#2028)
  * Futhark: Add missing tokens (#2118)
  * Gherkin: Add ``But`` (#2046)
  * Inform6: Update to 6.36 (#2050)
  * LilyPond:
  - Fix incorrect lexing of names containing a built-in (#2071)
  - Fix properties containing dashes (#2099)
  * PHP: Update builtin function and keyword list (#2054, #2056)
  * Scheme: Various improvements (#2060)
  * Spice: Update the keyword list, add new types (#2063, #2067)
  * Terraform:
  - Support non-idiomatic comments (#2065, #2066)
  - Fix class name lexing (#2097)
  - Add ``plugins`` argument to ``get_all_lexers()``.
  - Bump minimal Python version to 3.6 (#2059)
  - Fix multiple lexers marking whitespace as ``Text`` (#2025)
  - Remove various redundant uses of ``re.UNICODE`` (#2058)
  - Associate ``.resource`` with the Robot framework (#2047)
  - Associate ``.cljc`` with Clojure (#2043)
  - Associate ``.tpp`` with C++ (#2031)
  - Remove traces of Python 2 from the documentation (#2039)
  - The ``native`` style was updated to meet the WCAG AAA contrast guidelines (#2038)
  - Fix various typos (#2030)
  - Fix ``Groff`` formatter not inheriting token styles correctly (#2024)
  - Various improvements to the CI (#2036)
  - The Ada lexer has been moved to a separate file (#2117)
- drop elpi_fix_catastrophic_backtracking.patch: upstream
* Sun Feb  6 2022 Benoît Monin <benoit.monin@gmx.fr>
- backport elpi_fix_catastrophic_backtracking.patch:
  fix build getting stuck when running the tests
- switch prep stage to autosetup
- remove commented-out shebang removal
* Wed Jan 12 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to 2.11.2:
  * Updated lexers:
    + C-family: Fix incorrect handling of labels (#2022, #1996,
    [#1182])
    + Java: Fixed an issue with record keywords result in Error
    tokens in some cases (#2018)
  * Fix links to line numbers not working correctly (#2014)
  * Remove underline from Whitespace style in the Tango theme
    (#2020)
  * Fix IRC and Terminal256 formatters not backtracking correctly
    for custom token types, resulting in some unstyled tokens
    (#1986)
* Mon Jan  3 2022 Martin Liška <mliska@suse.cz>
- Update to 2.11.1:
  https://github.com/pygments/pygments/blob/master/CHANGES
- Remove one test as it requires wcag-contrast-ratio Python package.
* Thu Sep  9 2021 Stefan Schubert <schubi@suse.de>
- Use libalternatives instead of update-alternatives.
* Thu Jul 15 2021 Matej Cepl <mcepl@suse.com>
- Update to 2.9.0:
  - This time the list of changes is truly too long, take a look
    at https://github.com/pygments/pygments/blob/master/CHANGES.
* Fri Jan 29 2021 Matej Cepl <mcepl@suse.com>
- Update to 2.7.4 (all what was in the update to 2.7.2 and above
  it) (CVE-2021-20270, bsc#1183169, CVE-2021-27291, bsc#1184812):
  * drops cve_2021_20270.patch, cve_2021_27291.patch in older dists
  - Updated lexers:
  * Ada (#1581)
  * HTML (#1615, #1614)
  * Java (#1594, #1586)
  * JavaScript (#1605, #1589, #1588)
  * JSON (#1569 -- this is a complete rewrite)
  * Lean (#1601)
  * LLVM (#1612)
  * Mason (#1592)
  * MySQL (#1555, #1551)
  * Rust (#1608)
  * Turtle (#1590, #1553)
  - Deprecated JsonBareObjectLexer, which is now identical to
    JsonLexer (#1600)
  - The ``ImgFormatter`` now calculates the exact character
    width, which fixes some issues with overlapping text (#1213,
    [#1611])
  - Documentation fixes (#1609, #1599, #1598)
  - Fixed duplicated Juttle language alias (#1604, #1606)
  - Added support for Kotlin scripts (#1587)
  - Removed CSS rule which forced margin to 0
* Fri Dec  4 2020 Matej Cepl <mcepl@suse.com>
- Revert to 2.6.1 (higher version break python-Pelican).
* Sat Oct 24 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 2.7.2:
  * Updated lexers:
    + Latex (PR#1517, #1516)
    + LLVM (PR#1565)
    + SPARQL (PR#1559)
  * Fixed Python console/traceback lexer problems with custom
    exceptions without messages (#1548)
  * Allow loading ttc fonts on Mac/image formatter (#1223)
  * Improve analyze_text across a variety of lexers (PR#1549)
  * Removed CSS rule which forced the vertical padding to 0 for
    line numbers (PR#1583, #1579)
  * Fix TNTLexer crashing on unexpected EOL (#1568, PR#1570)
  * regexlint can be now run locally as part of tox tests (PR#1557)
  * Fix typos (PR#1550, #1562)
  * Add Python 3.9 as a supported version (PR#1554)
- drop shebang removal in _usd_builtins.py: fixed upstream
* Thu Sep 17 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 2.7.1:
  * Fixed a regression in the JSON lexer (#1544)
* Sun Sep 13 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 2.7.0:
  * Added lexers:
    + Arrow (PR#1481, PR#1499)
    + BARE (PR#1488)
    + Devicetree (PR#1434)
    + F* (PR#1409)
    + GDScript (PR#1457)
    + Pointless (PR#1494)
    + PromQL (PR#1506)
    + PsySH (PR#1438)
    + Singularity (PR#1285)
    + TiddlyWiki5 (PR#1390)
    + TNT (PR#1414)
    + YANG (PR#1408, PR#1428)
  * Updated lexers:
    + APL (PR#1503)
    + C++ (PR#1350, which also fixes: #1222, #996, #906, #828,
    [#1162], #1166, #1396)
    + Chapel (PR#1423)
    + CMake (#1491)
    + CSound (#1509)
    + Cython (PR#1507)
    + Dart (PR#1449)
    + Fennel (PR#1535)
    + Fortran (PR#1442)
    + GAS (PR#1530)
    + HTTP (PR#1432, #1520, PR#1521)
    + Inform 6 (PR#1461)
    + Javascript (PR#1533)
    + JSON (#1065, PR#1528)
    + Lean (PR#1415)
    + Matlab (PR#1399)
    + Markdown (#1492, PR#1495)
    + MySQL (#975, #1063, #1453, PR#1527)
    + NASM (PR#1465)
    + Nim (PR#1426)
    + PostgreSQL (PR#1513)
    + PowerShell (PR#1398, PR#1497)
    + Protobuf (PR#1505)
    + Robot (PR#1480)
    + SQL (PR#1402)
    + SystemVerilog (PR#1436, PR#1452, PR#1454, PR#1460, PR#1462,
    PR#1463, PR#1464, PR#1471, #1496, PR#1504)
    + TeraTerm (PR#1337)
    + XML (#1502)
  * Added a new filter for math symbols (PR#1406)
  * The Kconfig lexer will match Kconfig derivative names now
    (PR#1458)
  * Improved HTML formatter output (PR#1500)
  * .markdown is now recognized as an extension for Markdown files
    (PR#1476)
  * Fixed line number colors for Solarized (PR#1477, #1356)
  * Improvements to exception handling (PR#1478)
  * Improvements to tests (PR#1532, PR#1533, PR#1539)
  * Various code cleanups (PR#1536, PR#1537, PR#1538)
- remove unnecessary executable bit on all source files
* Tue Apr 14 2020 Matej Cepl <mcepl@suse.com>
- Don't use %%python3_only command, but properly use alternatives.
* Wed Mar 18 2020 Benoît Monin <benoit.monin@gmx.fr>
- fix the path of non-oss licensed files to remove
* Fri Mar 13 2020 Benoît Monin <benoit.monin@gmx.fr>
- set the minimal version of python to 3.5 to match upstream
  requirement
* Mon Mar  9 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 2.6.1:
  * This release fixes a packaging issue. No functional changes.
- additional changes from version 2.6.0:
  * Running Pygments on Python 2.x is no longer supported.
  * Added lexers:
    + Linux kernel logs (PR#1310)
    + LLVM MIR (PR#1361)
    + MiniScript (PR#1397)
    + Mosel (PR#1287, PR#1326)
    + Parsing Expression Grammar (PR#1336)
    + ReasonML (PR#1386)
    + Ride (PR#1319, PR#1321)
    + Sieve (PR#1257)
    + USD (PR#1290)
    + WebIDL (PR#1309)
  * Updated lexers:
    + Apache2 (PR#1378)
    + Chapel (PR#1357)
    + CSound (PR#1383)
    + D (PR#1375, PR#1362)
    + Idris (PR#1360)
    + Perl6/Raku lexer (PR#1344)
    + Python3 (PR#1382, PR#1385)
    + Rust: Updated lexer to cover more builtins (mostly macros)
    and miscellaneous new syntax (PR#1320)
    + SQL: Add temporal support keywords (PR#1402)
  * The 256-color/true-color terminal formatters now support the
    italic attribute in styles (PR#1288)
  * Support HTTP 2/3 header (PR#1308)
  * Support missing reason in HTTP header (PR#1322)
  * Boogie/Silver: support line continuations and triggers, move
    contract keywords to separate category (PR#1299)
  * GAS: support C-style comments (PR#1291)
  * Fix names in S lexer (PR#1330, PR#1333)
  * Fix numeric literals in Ada (PR#1334)
  * Recognize .mjs files as Javascript (PR#1392)
  * Recognize .eex files as Elixir (PR#1387)
  * Fix re.MULTILINE usage (PR#1388)
  * Recognize pipenv and poetry dependency & lock files (PR#1376)
  * Improve font search on Windows (#1247)
  * Remove unused script block (#1401)
- disable python2 build: Pygments is python 3 only now
- remove shebang from pygments/lexers/_usd_builtins.py: unneeded
* Sun Dec  8 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 2.5.2:
  * Fix incompatibility with some setuptools versions (PR#1316)
  * Fix lexing of ReST field lists (PR#1279)
  * Fix lexing of Matlab keywords as field names (PR#1282)
  * Recognize double-quoted strings in Matlab (PR#1278)
  * Avoid slow backtracking in Vim lexer (PR#1312)
  * Fix Scala highlighting of types (PR#1315)
  * Highlight field lists more consistently in ReST (PR#1279)
  * Fix highlighting Matlab keywords in field names (PR#1282)
  * Recognize Matlab double quoted strings (PR#1278)
  * Add some Terraform keywords
  * Update Modelica lexer to 3.4
  * Update Crystal examples
- additional changes from version 2.5.1:
  * This release fixes a packaging issue. No functional changes.
- additional changes from version 2.5.0:
  * Added lexers:
    + Email (PR#1246)
    + Erlang, Elxir shells (PR#823, #1521)
    + Notmuch (PR#1264)
    + Scdoc (PR#1268)
    + Solidity (#1214)
    + Zeek (new name for Bro) (PR#1269)
    + Zig (PR#820)
  * Updated lexers:
    + Apache2 Configuration (PR#1251)
    + Bash sessions (#1253)
    + CSound (PR#1250)
    + Dart
    + Dockerfile
    + Emacs Lisp
    + Handlebars (PR#773)
    + Java (#1101, #987)
    + Logtalk (PR#1261)
    + Matlab (PR#1271)
    + Praat (PR#1277)
    + Python3 (PR#1255)
    + Ruby
    + YAML (#1528)
    + Velocity
  * Added styles:
    + Inkpot (PR#1276)
  * The PythonLexer class is now an alias for the former
    Python3Lexer. The old PythonLexer is available as Python2Lexer.
  * Bump NasmLexer priority over TasmLexer for .asm files
    (fixes #1326)
  * Default font in the ImageFormatter has been updated
    (#928, PR#1245)
  * Test suite switched to py.test, removed nose dependency (#1490)
  * Reduce TeraTerm lexer score -- it used to match nearly all
    languages (#1256)
  * Treat Skylark/Starlark files as Python files (PR#1259)
  * Image formatter: actually respect line_number_separator option
  * Add LICENSE file to wheel builds
  * Agda: fix lambda highlighting
  * Dart: support @ annotations
  * Dockerfile: accept FROM ... AS syntax
  * Emacs Lisp: add more string functions
  * GAS: accept registers in directive arguments
  * Java: make structural punctuation (braces, parens, colon,
    comma) Punctuation, not Operator (#987)
  * Java: support var contextual keyword (#1101)
  * Matlab: Fix recognition of function keyword (PR#1271)
  * Python: recognize .jy filenames (#976)
  * Python: recognize f string prefix (#1156)
  * Ruby: support squiggly heredocs
  * Shell sessions: recognize Virtualenv prompt (PR#1266)
  * Velocity: support silent reference syntax
- drop denose.patch: fixed upstream
- fix postuninstall alternative
* Tue Jun  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.4.2:
  - Fix encoding error when guessing lexer with given ``encoding`` option
    (#1438)
  - Updated lexers:
  * Coq (#1430)
  * MSDOS Session (PR#734)
  * NASM (#1517)
  * Objective-C (PR#813, #1508)
  * Prolog (#1511)
  * TypeScript (#1515)
  - Support CSS variables in stylesheets (PR#814, #1356)
  - Fix F# lexer name (PR#709)
  - Fix ``TerminalFormatter`` using bold for bright text (#1480)
* Mon May 20 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.4.0
  * Add solarized style
  * Add support for Markdown reference-style links
  * Add license information to generated HTML/CSS files
  * Change ANSI color names
  * Fix catastrophic backtracking in the bash lexer
  * Fix documentation failing to build using Sphinx 2.0
  * Fix incorrect links in the Lisp and R lexer documentation
  * Fix rare unicode errors on Python 2.7
  * Fix lexers popping from an empty stack
  * TypoScript uses .typoscript now
  * Updated Trove classifiers and pip requirements
* Mon Apr  1 2019 Matej Cepl <mcepl@suse.com>
- Refresh denose.patch to make whole test suite to pass.
  bt#birkenfeld/pygments-main#1490
* Mon Feb 11 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid name in summary (rpmlint).
- Ensure neutrality of description.
* Mon Feb 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.3.1:
  * Update lexers
  * Minimum Python versions changed to 2.7 and 3.5
  * Added support for Python 3.7 generator changes (PR#772)
  * Fix incorrect token type in SCSS for single-quote strings (#1322)
  * Use `terminal256` formatter if `TERM` contains `256` (PR#666)
  * Fix incorrect handling of GitHub style fences in Markdown (PR#741, #1389)
  * Fix `%%a` not being highlighted in Python3 strings (PR#727)
- Drop patch python_37.diff which was merged upstream
- Refresh patch denose.patch
* Thu Jan 10 2019 Matej Cepl <mcepl@suse.com>
- Added denose.patch removing dependency on the nose package.
  https://bitbucket.org/birkenfeld/pygments-main/issues/1490/remove-nose-dependency
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Jul 16 2018 mimi.vx@gmail.com
- add python_37.diff  - fixes build with python-3.7+
* Tue Aug 15 2017 dmueller@suse.com
- fix build in a python2.x only env
* Fri Apr  7 2017 toddrme2178@gmail.com
- Use https url.
* Fri Apr  7 2017 toddrme2178@gmail.com
- Update source url.
* Fri Apr  7 2017 toddrme2178@gmail.com
- Update to 2.2.0
  - Added the ability to load lexer and formatter classes directly from files
    with the `-x` command line option and the `lexers.load_lexer_from_file()`
    and `formatters.load_formatter_from_file()` functions. (PR#559)
  - Added `lexers.find_lexer_class_by_name()`. (#1203)
  - Added new token types and lexing for magic methods and variables in Python
    and PHP.
  - Added a new token type for string affixes and lexing for them in Python, C++
    and Postgresql lexers.
  - Added a new token type for heredoc (and similar) string delimiters and
    lexing for them in C++, Perl, PHP, Postgresql and Ruby lexers.
  - Styles can now define colors with ANSI colors for use in the 256-color
    terminal formatter. (PR#531)
  - Improved the CSS lexer. (#1083, #1130)
  - Added "Rainbow Dash" style. (PR#623)
  - Delay loading `pkg_resources`, which takes a long while to import. (PR#690)
* Wed Apr  5 2017 tbechtold@suse.com
- Fix python_module macro definition
* Thu Dec  8 2016 jmatejek@suse.com
- update for multipython build
- only distribute "pygmentize" for Python 3
* Mon Oct 17 2016 dmueller@suse.com
- update to 2.1.3:
  - Fixed regression in Bash lexer (PR#563)
  - Fixed Python 3 regression in image formatter (#1215)
  - Fixed regression in Bash lexer (PR#562)
* Sun Feb 14 2016 michael@stroeder.com
- Update to version 2.1.1
  - Fixed Jython compatibility (#1205)
  - Fixed HTML formatter output with leading empty lines (#1111)
  - Added a mapping table for LaTeX encodings and added utf8 (#1152)
  - Fixed image formatter font searching on Macs (#1188)
  - Fixed deepcopy-ing of Token instances (#1168)
  - Fixed Julia string interpolation (#1170)
  - Fixed statefulness of HttpLexer between get_tokens calls
  - Many smaller fixes to various lexers
* Tue Feb  9 2016 olaf@aepfle.de
- Disable testsuite in SLE_11 because it requires python 2.7
* Mon Jan 25 2016 michael@stroeder.com
- Update to version 2.1
  - Added styles:
  * Lovelace (PR#456)
  * Algol and Algol-nu (#1090)
  - Added formatters:
  * IRC (PR#458)
  * True color (24-bit) terminal ANSI sequences (#1142)
    (formatter alias: "16m")
  - New "filename" option for HTML formatter (PR#527).
  - Improved performance of the HTML formatter for long lines (PR#504).
  - Updated autopygmentize script (PR#445).
  - Fixed style inheritance for non-standard token types in HTML output.
  - Added support for async/await to Python 3 lexer.
  - Rewrote linenos option for TerminalFormatter (it's better, but slightly
    different output than before) (#1147).
  - Javascript lexer now supports most of ES6 (#1100).
  - Cocoa builtins updated for iOS 8.1 (PR#433).
  - Combined BashSessionLexer and ShellSessionLexer, new version should support
    the prompt styles of either.
  - Added option to pygmentize to show a full traceback on exceptions.
  - Fixed incomplete output on Windows and Python 3 (e.g. when using iPython
    Notebook) (#1153).
  - Allowed more traceback styles in Python console lexer (PR#253).
  - Added decorators to TypeScript (PR#509).
  - Fix highlighting of certain IRC logs formats (#1076).
* Wed Mar 11 2015 tbehrens@suse.com
- Update to version 2.0.2:
  * Fix Python tracebacks getting duplicated in the console lexer
  * Backquote-delimited identifiers are now recognized in F#
  * Fix an encoding issue when using pygmentize with the -o option.
  * Default lexer encoding is now “guess”
  * Major update to Swift lexer.
  * Multiple fixes to lexer guessing in conflicting cases
  * Simplified regexes and builtin lists.
  * Dropped Python 2.4 and 2.5 compatibility
  * Lexers added:
    APL (#969)
    Agda and Literate Agda (PR#203)
    Alloy (PR#355)
    AmbientTalk
    BlitzBasic (PR#197)
    ChaiScript (PR#24)
    Chapel (PR#256)
    Cirru (PR#275)
    Clay (PR#184)
    ColdFusion CFC (PR#283)
    Cryptol and Literate Cryptol (PR#344)
    Cypher (PR#257)
    Docker config files
    EBNF (PR#193)
    Eiffel (PR#273)
    GAP (PR#311)
    Golo (PR#309)
    Handlebars (PR#186)
    Hy (PR#238)
    Idris and Literate Idris (PR#210)
    Igor Pro (PR#172)
    Inform 6/7 (PR#281)
    Intel objdump (PR#279)
    Isabelle (PR#386)
    Jasmin (PR#349)
    JSON-LD (PR#289)
    Kal (PR#233)
    Lean (PR#399)
    LSL (PR#296)
    Limbo (PR#291)
    Liquid (#977)
    MQL (PR#285)
    MaskJS (PR#280)
    Mozilla preprocessors
    Mathematica (PR#245)
    NesC (PR#166)
    Nit (PR#375)
    Nix (PR#267)
    Pan
    Pawn (PR#211)
    Perl 6 (PR#181)
    Pig (PR#304)
    Pike (PR#237)
    QBasic (PR#182)
    Red (PR#341)
    ResourceBundle (#1038)
    Rexx (PR#199)
    Rql (PR#251)
    Rsl
    SPARQL (PR#78)
    Slim (PR#366)
    Swift (PR#371)
    Swig (PR#168)
    TADS 3 (PR#407)
    Todo.txt todo lists
    Twig (PR#404)
  * Added a helper to “optimize” regular expressions
  * New styles: “xcode” and “igor”
  * The command-line “pygmentize” tool now tries a little harder
  * Added “inencoding” option for lexers to override “encoding”
  * Added line-by-line “streaming” mode for pygmentize with the “-s” option
  * Added an “envname” option to the LaTeX formatter to select a replacement
  * Updated the Makefile lexer to yield a little more useful highlighting.
  * Lexer aliases passed to get_lexer_by_name() are now case-insensitive.
  * File name matching in lexers and formatters will now use a regex cache for speed
  * Pygments will now recognize “vim” modelines when guessing the lexer
  * Major restructure of the pygments.lexers module namespace.
  * The NameHighlightFilter now works with any Name.* token type (#790).
  * Python 3 lexer: add new exceptions from PEP 3151.
  * Opa lexer: add new keywords (PR#170).
  * Julia lexer: add keywords and underscore-separated number literals
  * Lasso lexer: fix method highlighting, update builtins
  * Objective C/C++ lexers: allow “@” prefixing any expression (#871).
  * Ruby lexer: fix lexing of Name::Space tokens (#860) and of symbols in hashes
  * Stan lexer: update for version 2.4.0 of the language
  * JavaScript lexer: add the “yield” keyword (PR#196).
  * HTTP lexer: support for PATCH method (PR#190).
  * Koka lexer: update to newest language spec (PR#201).
  * Haxe lexer: rewrite and support for Haxe 3 (PR#174).
  * Prolog lexer: add different kinds of numeric literals
  * F# lexer: rewrite with newest spec for F# 3.0 (#842), fix a bug with dotted chains
  * Kotlin lexer: general update (PR#271).
  * Rebol lexer: fix comment detection and analyse_text (PR#261).
  * LLVM lexer: update keywords to v3.4 (PR#258).
  * PHP lexer: add new keywords and binary literals (PR#222).
  * external/markdown-processor.py updated to newest python-markdown
  * CSS lexer: some highlighting order fixes (PR#231).
  * Ceylon lexer: fix parsing of nested multiline comments (#915).
  * C family lexers: fix parsing of indented preprocessor directives
  * Rust lexer: update to 0.9 language version (PR#270, PR#388).
  * Elixir lexer: update to 0.15 language version (PR#392).
  * Fix swallowing incomplete tracebacks in Python console lexer
* Mon Apr  7 2014 dmueller@suse.com
- add LICENSE to doc section
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri May  3 2013 toddrme2178@gmail.com
- Update to version 1.6:
  - Lexers added
  - Fix unquoted HTML attribute lexing in Opa .
  - The HTML formatter now supports linking to tags using CTags files, when the
    python-ctags package is installed .
  - The HTML formatter now has a "linespans" option that wraps every line in a
    <span> tag with a specific id .
  - When deriving a lexer from another lexer with token definitions, definitions
    for states not in the child lexer are now inherited.  If you override a state
    in the child lexer, an "inherit" keyword has been added to insert the base
    state at that position .
  - The C family lexers now inherit token definitions from a common base class,
    removing code duplication .
  - Use "colorama" on Windows for console color output .
  - Fix Template Haskell highlighting .
  - Fix some S/R lexer errors .
  - Fix a bug in the Prolog lexer with names that start with 'is' .
  - Rewrite Dylan lexer, add Dylan LID lexer .
  - Add a Java quickstart document .
  - Add a "external/autopygmentize" file that can be used as .lessfilter .
* Thu May  3 2012 toddrme2178@gmail.com
- Removed files with non-oss license, see bnc#760344
- Cleanups in python 2 and python 3 spec files
* Mon Apr 30 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4 x86_64
* Mon Mar 12 2012 saschpe@gmx.de
- Update to version 1.5:
  - Fix Python 3 terminal highlighting with pygmentize
  - In the LaTeX formatter, escape special &, < and > chars
  - In the LaTeX formatter, fix display problems for styles with token
    background colors
  - Enhancements to the Squid conf lexer
  - Several fixes to the reStructuredText lexer
  - Recognize methods in the ObjC lexer
  - Fix Lua "class" highlighting: it does not have classes
  - Fix degenerate regex in Scala lexer  and highlighting bugs
  - Fix number pattern order in Ocaml lexer
  - Fix generic type highlighting in ActionScript 3
  - Fixes to the Clojure lexer
  - Fix degenerate regex in Nemerle lexer
  - Fix infinite looping in CoffeeScript lexer
  - Fix crashes and analysis with ObjectiveC lexer
  - Add some Fortran 2003 keywords.
  - Fix Boo string regexes
  - Add "rrt" style
  - Fix infinite looping in Darcs Patch lexer.
  - Lots of misc fixes to character-eating bugs and ordering problems in many
    different lexers.
* Tue Jan 24 2012 bwiedemann@suse.com
- fix Obsoletes
* Fri Sep 23 2011 saschpe@suse.de
- Disable tests again, breaks i586 build
* Thu Sep 22 2011 saschpe@suse.de
- Fixed license to BSD-2-Clause
* Sun Sep 11 2011 saschpe@gmx.de
- Change license to BSD-3-Clause (SPDX style)
- Removed %%clean section (has sane default)
- Added python-distribute requirement
* Sun Jul  3 2011 saschpe@gmx.de
- Renamed to 'python-Pygments', obsoletes 'python-pygments'
* Mon Feb 21 2011 nix@opensuse.org
- Update to version 1.4
- Compress the tarball with bz2
* Tue Sep 14 2010 coolo@novell.com
- correct email addresses
* Fri Jun 18 2010 coolo@novell.com
- update to 1.3.1 (1.4 is too late, but is known to fix
  http://dev.pocoo.org/projects/pygments/ticket/507 )
* Fri Feb 12 2010 bitdealer@opensuse.org
- Updated to 1.2.2
* Fri Oct  9 2009 bitdealer@opensuse.org
- Updated to 1.1.1
* Tue Dec  9 2008 cfarrell1980@gmail.com
- Updated to version 1.0
* Thu Jun 21 2007 judas_iscariote@shorewall.net
- Initial package version.
